#This Tcl file is written for demostrating tcl commands for Heat Transfer module in OpenSees
#The steel beam subjected to Localised Fire (Eurocode1 Localised Fire Model)

#Dimension of beam
set BF 0.20;  #Width of flange (m)
set HB 0.40;  #Height of beam (m)
set Tw 0.013; #Thickness of web (m)
set Tf 0.015; #Thickness of flange (m)
set Len 6.0;  #Length of beam (m)
set Centrex 0.0
#Centrey=HB/2.0
set Centrey [expr $HB/2.0]
#Centrez=Len/2.0
set Centrez [expr $Len/2.0]

#Mesh sizes
set elex [expr ($BF-$Tw)/8.0]
set eleweby [expr ($HB-$Tf*2.0)/10.0]
set eley [expr $Tf/2.0]
set elewebx [expr $Tw/2.0]
set elez [expr $Len/120.0]

wipe;

#HeatTransfer activates the HTModule. 2D ,or 2d, or 3D or 3d indicate the model dimension.
HeatTransfer 3D;
        
#Defining HeatTransfer Material with Material tag 1.
HTMaterial CarbonSteelEC3 1;       

#HTEntity Isection3d $tag   $centreX   $centreY  $centreZ   $Bf   $HB  $Tw    $Tf   $Len;
HTEntity  Isection3D   1    $Centrex   $Centrey  $Centrez   $BF   $HB  $Tw    $Tf   $Len;

#HTMesh $MeshTag $EntityTag  $MaterialTag -SecondMat 2
HTMesh 1 1 1 -phaseChange 0 -MeshCtrls $elex $eley $elez $elewebx $eleweby

HTMeshAll;
puts "mesh done";

#Defining Initial Temperature (K);
SetInitialT 293.15;

#Defining HeatTransfer constants $consTag $hc(W/m^2∙K) $Ta $ε $a
HTConstants 1 35.0 293.15 0.85 0.85; 

#Defining HeatTransfer Boundary Pattern
#'AmbientBC' $patTag
HTPattern AmbientBC 1 {
	HeatFluxBC -HTEntity 1 -face  1 4 5 6 7 8 9  -type -ConvecAndRad -HTConstants 1;
}

#FireModel - the Eurocode 1 Localised Fire Model
#$fireTYype $fireTag $firePars
FireModel Localised 1 -origin 0.0 -2.0 $Centrez -firePars 1.0 1127.0E3 2.4 2 ; # Diameter of Fire, Total HRR, Ceilling Height, symetrical axis

puts "Fire done";

#Defining HeatFlux Boundary Condition 
#'fire' $patTag, 'model' $fireTag
HTPattern fire 2 model 1 {
	HeatFluxBC -HTEntity 1 -face 1  -type -Prescribed -HTConstants 1 -par 4; #Fire action using input heat flux
	HeatFluxBC -HTEntity 1 -face 4 5  -type -Prescribed -HTConstants 1 -par 3;
	HeatFluxBC -HTEntity 1 -face 6 7  -type -Prescribed -HTConstants 1 -par 2;
	HeatFluxBC -HTEntity 1 -face 8 9  -type -Prescribed -HTConstants 1 -par 1;
	#'HTEntitiy' $entTag, 'face' $fTag, 'type' $HFType, 'HTConstants' consTag
	#-par is to set extra tags for SFPE beam-ceiling localised fire model. User can leave as it is

}

#HeatTransfer Recorder
set flloc [expr ($BF-$Tw)/4.0+$Tw/2]
set webloc [expr  $HB/2]
HTNodeSet 10 -Locx $flloc -Locy 0.0075;
HTNodeSet 11 -Locx 0.0 -Locy $webloc;
HTNodeSet 12 -Locx $flloc -Locy 0.3925;

HTRecorder -file tempBLF.out -NodeSet 10;    #Nodes of beam lower flange
HTRecorder -file tempWeb.out -NodeSet 11;    #monitored nodes of beam web
HTRecorder -file tempBUF.out -NodeSet 12;    #monitored nodes for beam upper flange

#HeatTransfer analysis
HTAnalysis HeatTransfer

#HeatTransfer Analyze No.of Steps timestep;
HTAnalyze 108 10;	

wipe;


